:github_url: https://github.com/stephane-caron/pink/tree/main/doc/references.rst

**********
References
**********

.. [FrameTaskJacobian] `Jacobian of a kinematic task and derivatives on manifolds <https://scaron.info/robotics/jacobian-of-a-kinematic-task-and-derivatives-on-manifolds.html>`_. S. Caron. 2023.

.. [MLT] `A micro Lie theory for state estimation in robotics <https://arxiv.org/abs/1812.01537>`_. J. Solà, J. Deray, D. Atchuthan. 2018.

.. [Sugihara2011] *Solvability-Unconcerned Inverse Kinematics by the Levenberg-Marquardt Method*. T. Sugihara. IEEE transactions on robotics, 2011, vol. 27, no 5, pp. 984-991.

.. [Flacco2015] *Control of Redundant Robots Under Hard Joint Constraints: Saturation in the Null Space*. F. Flacco, A. De Luca and O. Khatib. IEEE Transactions on Robotics, 2015, vol. 31, no 3, pp. 637-654.

.. [DelPrete2018] *Joint Position and Velocity Bounds in Discrete-Time Acceleration/Torque Control of Robot Manipulators*. A. Del Prete. IEEE Robotics and Automation Letters, 2018, vol. 3, no 1, pp. 281-288.
